@@ -4,16 +4,15 @@ from django.contrib.auth import (authenticate, login as auth_login,
 from django.contrib.auth.decorators import login_required
 from django.contrib.messages import info, error
 from django.core.urlresolvers import NoReverseMatch
+from django.http import Http404
 from django.shortcuts import get_object_or_404, redirect
-from django.utils.datastructures import SortedDict
 from django.utils.translation import ugettext_lazy as _
 
-from mezzanine.accounts import get_profile_model, get_profile_user_fieldname
 from mezzanine.utils.models import get_user_model
 from mezzanine.accounts import get_profile_form
 from mezzanine.accounts.forms import LoginForm, PasswordResetForm
 from mezzanine.conf import settings
-from mezzanine.utils.email import send_verification_mail
+from mezzanine.utils.email import send_verification_mail, send_approve_mail
 from mezzanine.utils.urls import login_redirect
 from mezzanine.utils.views import render
 
@@ -31,7 +30,7 @@ def login(request, template="accounts/account_login.html"):
         info(request, _("Successfully logged in"))
         auth_login(request, authenticated_user)
         return login_redirect(request)
-    context = {"form": form, "title": _("Login")}
+    context = {"form": form, "title": _("Log in")}
     return render(request, template, context)
 
 
@@ -53,15 +52,20 @@ def signup(request, template="accounts/account_signup.html"):
     if request.method == "POST" and form.is_valid():
         new_user = form.save()
         if not new_user.is_active:
-            send_verification_mail(request, new_user, "signup_verify")
-            info(request, _("A verification email has been sent with "
-                            "a link for activating your account."))
+            if settings.ACCOUNTS_APPROVAL_REQUIRED:
+                send_approve_mail(request, new_user)
+                info(request, _("Thanks for signing up! You'll receive "
+                                "an email when your account is activated."))
+            else:
+                send_verification_mail(request, new_user, "signup_verify")
+                info(request, _("A verification email has been sent with "
+                                "a link for activating your account."))
             return redirect(request.GET.get("next", "/"))
         else:
             info(request, _("Successfully signed up"))
             auth_login(request, new_user)
             return login_redirect(request)
-    context = {"form": form, "title": _("Signup")}
+    context = {"form": form, "title": _("Sign up")}
     return render(request, template, context)
 
 
@@ -72,6 +76,8 @@ def signup_verify(request, uidb36=None, token=None):
     is set to ``True``. Activates the user and logs them in,
     redirecting to the URL they tried to access when signing up.
     """
+    if settings.ACCOUNTS_APPROVAL_REQUIRED:
+        raise Http404
     user = authenticate(uidb36=uidb36, token=token, is_active=False)
     if user is not None:
         user.is_active = True
@@ -97,25 +103,8 @@ def profile(request, username, template="accounts/account_profile.html"):
     """
     Display a profile.
     """
-    profile_user = get_object_or_404(
-        User,
-        username__iexact=username,
-        is_active=True
-    )
-    profile_fields = SortedDict()
-    Profile = get_profile_model()
-    if Profile is not None:
-        profile = profile_user.get_profile()
-        user_fieldname = get_profile_user_fieldname()
-        exclude = tuple(settings.ACCOUNTS_PROFILE_FORM_EXCLUDE_FIELDS)
-        for field in Profile._meta.fields:
-            if field.name not in ("id", user_fieldname) + exclude:
-                value = getattr(profile, field.name)
-                profile_fields[field.verbose_name.title()] = value
-    context = {
-        "profile_user": profile_user,
-        "profile_fields": profile_fields.items(),
-    }
+    lookup = {"username__iexact": username, "is_active": True}
+    context = {"profile_user": get_object_or_404(User, **lookup)}
     return render(request, template, context)
 
 
