@@ -2,6 +2,7 @@
 from django import forms
 
 from mezzanine.blog.models import BlogPost
+from mezzanine.core.models import CONTENT_STATUS_DRAFT
 
 
 # These fields need to be in the form, hidden, with default values,
@@ -25,6 +26,7 @@ class BlogPostForm(forms.ModelForm):
         initial = {}
         for field in hidden_field_defaults:
             initial[field] = BlogPost._meta.get_field(field).default
+        initial["status"] = CONTENT_STATUS_DRAFT
         super(BlogPostForm, self).__init__(initial=initial)
         for field in hidden_field_defaults:
             self.fields[field].widget = forms.HiddenInput()
