@@ -35,21 +35,29 @@ class BlogPost(Displayable, Ownable, RichText, AdminThumbMixin):
 
     @models.permalink
     def get_absolute_url(self):
+        """
+        URLs for blog posts can either be just their slug, or prefixed
+        with a portion of the post's publish date, controlled by the
+        setting ``BLOG_URLS_DATE_FORMAT``, which can contain the value
+        ``year``, ``month``, or ``day``. Each of these maps to the name
+        of the corresponding urlpattern, and if defined, we loop through
+        each of these and build up the kwargs for the correct urlpattern.
+        The order which we loop through them is important, since the
+        order goes from least granualr (just year) to most granular
+        (year/month/day).
+        """
         url_name = "blog_post_detail"
         kwargs = {"slug": self.slug}
-        if settings.BLOG_URLS_USE_DATE:
-            url_name = "blog_post_detail_date"
-            month = str(self.publish_date.month)
-            if len(month) == 1:
-                month = "0" + month
-            day = str(self.publish_date.day)
-            if len(day) == 1:
-                day = "0" + day
-            kwargs.update({
-                "day": day,
-                "month": month,
-                "year": self.publish_date.year,
-            })
+        date_parts = ("year", "month", "day")
+        if settings.BLOG_URLS_DATE_FORMAT in date_parts:
+            url_name = "blog_post_detail_%s" % settings.BLOG_URLS_DATE_FORMAT
+            for date_part in date_parts:
+                date_value = str(getattr(self.publish_date, date_part))
+                if len(date_value) == 1:
+                    date_value = "0%s" % date_value
+                kwargs[date_part] = date_value
+                if date_part == settings.BLOG_URLS_DATE_FORMAT:
+                    break
         return (url_name, (), kwargs)
 
     # These methods are deprecated wrappers for keyword and category
