@@ -1,8 +1,9 @@
 
 from optparse import make_option
 
-from django.core.management.base import NoArgsCommand
+from django.core.management.base import NoArgsCommand, CommandError
 from django.core.management.commands import syncdb
+from django.db import connection
 
 from mezzanine.core.management import install_optional_data
 from mezzanine.conf import settings
@@ -21,6 +22,10 @@ class Command(NoArgsCommand):
         verbosity = int(options.get("verbosity", 0))
         interactive = int(options.get("interactive", 0))
         no_data = int(options.get("nodata", 0))
+        if "conf_setting" in connection.introspection.table_names():
+            raise CommandError("Database already created, you probably "
+                               "want the syncdb or migrate command")
+
         syncdb.Command().execute(**options)
         if not interactive and not no_data:
             install_optional_data(verbosity)
