@@ -7,6 +7,7 @@ from django import forms
 from django.forms.extras import SelectDateWidget
 from django.core.files.storage import FileSystemStorage
 from django.core.urlresolvers import reverse
+from django.template import Template
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 from django.utils.timezone import now
@@ -14,16 +15,37 @@ from django.utils.timezone import now
 from mezzanine.conf import settings
 from mezzanine.forms import fields
 from mezzanine.forms.models import FormEntry, FieldEntry
+from mezzanine.utils.email import split_addresses as split_choices
 
 
 fs = FileSystemStorage(location=settings.FORMS_UPLOAD_ROOT)
 
+##############################
+# Each type of export filter #
+##############################
+
+# Text matches
 FILTER_CHOICE_CONTAINS = "1"
 FILTER_CHOICE_DOESNT_CONTAIN = "2"
+
+# Exact matches
 FILTER_CHOICE_EQUALS = "3"
 FILTER_CHOICE_DOESNT_EQUAL = "4"
+
+# Greater/less than
 FILTER_CHOICE_BETWEEN = "5"
 
+# Multiple values
+FILTER_CHOICE_CONTAINS_ANY = "6"
+FILTER_CHOICE_CONTAINS_ALL = "7"
+FILTER_CHOICE_DOESNT_CONTAIN_ANY = "8"
+FILTER_CHOICE_DOESNT_CONTAIN_ALL = "9"
+
+##########################
+# Export filters grouped #
+##########################
+
+# Text fields
 TEXT_FILTER_CHOICES = (
     ("", _("Nothing")),
     (FILTER_CHOICE_CONTAINS, _("Contains")),
@@ -32,17 +54,29 @@ TEXT_FILTER_CHOICES = (
     (FILTER_CHOICE_DOESNT_EQUAL, _("Doesn't equal")),
 )
 
+# Choices with single value entries
 CHOICE_FILTER_CHOICES = (
     ("", _("Nothing")),
-    (FILTER_CHOICE_EQUALS, _("Equals")),
-    (FILTER_CHOICE_DOESNT_EQUAL, _("Doesn't equal")),
+    (FILTER_CHOICE_CONTAINS_ANY, _("Equals any")),
+    (FILTER_CHOICE_DOESNT_CONTAIN_ANY, _("Doesn't equal any")),
 )
 
+# Choices with multiple value entries
+MULTIPLE_FILTER_CHOICES = (
+    ("", _("Nothing")),
+    (FILTER_CHOICE_CONTAINS_ANY, _("Contains any")),
+    (FILTER_CHOICE_CONTAINS_ALL, _("Contains all")),
+    (FILTER_CHOICE_DOESNT_CONTAIN_ANY, _("Doesn't contain any")),
+    (FILTER_CHOICE_DOESNT_CONTAIN_ALL, _("Doesn't contain all")),
+)
+
+# Dates
 DATE_FILTER_CHOICES = (
     ("", _("Nothing")),
     (FILTER_CHOICE_BETWEEN, _("Is between")),
 )
 
+# The filter function for each filter type
 FILTER_FUNCS = {
     FILTER_CHOICE_CONTAINS:
         lambda val, field: val.lower() in field.lower(),
@@ -53,15 +87,29 @@ FILTER_FUNCS = {
     FILTER_CHOICE_DOESNT_EQUAL:
         lambda val, field: val.lower() != field.lower(),
     FILTER_CHOICE_BETWEEN:
-        lambda val_from, val_to, field: val_from <= field <= val_to
+        lambda val_from, val_to, field: (
+            (not val_from or val_from <= field) and
+            (not val_to or val_to >= field)
+        ),
+    FILTER_CHOICE_CONTAINS_ANY:
+        lambda val, field: set(val) & set(split_choices(field)),
+    FILTER_CHOICE_CONTAINS_ALL:
+        lambda val, field: set(val) == set(split_choices(field)),
+    FILTER_CHOICE_DOESNT_CONTAIN_ANY:
+        lambda val, field: not set(val) & set(split_choices(field)),
+    FILTER_CHOICE_DOESNT_CONTAIN_ALL:
+        lambda val, field: set(val) != set(split_choices(field)),
 }
 
+# Export form fields for each filter type grouping
 text_filter_field = forms.ChoiceField(label=" ", required=False,
-    choices=TEXT_FILTER_CHOICES)
+                                      choices=TEXT_FILTER_CHOICES)
 choice_filter_field = forms.ChoiceField(label=" ", required=False,
-    choices=CHOICE_FILTER_CHOICES)
+                                        choices=CHOICE_FILTER_CHOICES)
+multiple_filter_field = forms.ChoiceField(label=" ", required=False,
+                                          choices=MULTIPLE_FILTER_CHOICES)
 date_filter_field = forms.ChoiceField(label=" ", required=False,
-    choices=DATE_FILTER_CHOICES)
+                                      choices=DATE_FILTER_CHOICES)
 
 
 class FormForForm(forms.ModelForm):
@@ -74,7 +122,7 @@ class FormForForm(forms.ModelForm):
         model = FormEntry
         exclude = ("form", "entry_time")
 
-    def __init__(self, form, *args, **kwargs):
+    def __init__(self, form, context, *args, **kwargs):
         """
         Dynamically add each of the form fields for the given form model
         instance and its related field model instances.
@@ -85,7 +133,7 @@ class FormForForm(forms.ModelForm):
         # If a FormEntry instance is given to edit, populate initial
         # with its field values.
         field_entries = {}
-        if "instance" in kwargs:
+        if kwargs.get("instance"):
             for field_entry in kwargs["instance"].fields.all():
                 field_entries[field_entry.field_id] = field_entry.value
         super(FormForForm, self).__init__(*args, **kwargs)
@@ -116,16 +164,19 @@ class FormForForm(forms.ModelForm):
             # - The default value for the field instance as given in
             #   the admin.
             #
+            initial_val = None
             try:
                 initial_val = field_entries[field.id]
             except KeyError:
                 try:
-                    self.initial[field_key] = initial[field_key]
+                    initial_val = initial[field_key]
                 except KeyError:
-                    self.initial[field_key] = field.default
-            else:
+                    initial_val = Template(field.default).render(context)
+            if initial_val:
                 if field.is_a(*fields.MULTIPLE):
-                    initial_val = [x.strip() for x in initial_val.split(",")]
+                    initial_val = split_choices(initial_val)
+                elif field.field_type == fields.CHECKBOX:
+                    initial_val = initial_val != "False"
                 self.initial[field_key] = initial_val
             self.fields[field_key] = field_class(**field_args)
 
@@ -221,6 +272,15 @@ class EntriesForm(forms.Form):
                     required=False)
                 self.fields["%s_filter" % field_key] = choice_filter_field
                 self.fields["%s_contains" % field_key] = contains_field
+            elif field.is_a(*fields.MULTIPLE):
+                # A fixed set of choices to filter by, with multiple
+                # possible values in the entry field.
+                contains_field = forms.MultipleChoiceField(label=" ",
+                    choices=field.get_choices(),
+                    widget=forms.CheckboxSelectMultiple(),
+                    required=False)
+                self.fields["%s_filter" % field_key] = multiple_filter_field
+                self.fields["%s_contains" % field_key] = contains_field
             elif field.is_a(*fields.DATES):
                 # A date range to filter by.
                 self.fields["%s_filter" % field_key] = date_filter_field
@@ -326,32 +386,22 @@ class EntriesForm(forms.Form):
                 if filter_type == FILTER_CHOICE_BETWEEN:
                     f, t = "field_%s_from" % field_id, "field_%s_to" % field_id
                     filter_args = [self.cleaned_data[f], self.cleaned_data[t]]
-                    if filter_args[0] is None or filter_args[1] is None:
-                        filter_args = None
                 else:
                     field_name = "field_%s_contains" % field_id
                     filter_args = self.cleaned_data[field_name]
                     if filter_args:
                         filter_args = [filter_args]
             if filter_args:
-                filter_func = FILTER_FUNCS[filter_type]
-                if isinstance(filter_args[0], list):
-                    # Criteria is from a range of checkboxes.
-                    for arg in filter_args[0]:
-                        if filter_func(arg, field_value):
-                            break
-                    else:
-                        valid_row = False
+                # Convert dates before checking filter.
+                if field_id in date_field_ids:
+                    y, m, d = field_value.split(" ")[0].split("-")
+                    dte = date(int(y), int(m), int(d))
+                    filter_args.append(dte)
                 else:
-                    # Convert dates before checking filter.
-                    if field_id in date_field_ids:
-                        y, m, d = field_value.split(" ")[0].split("-")
-                        dte = date(int(y), int(m), int(d))
-                        filter_args.append(dte)
-                    else:
-                        filter_args.append(field_value)
-                    if not filter_func(*filter_args):
-                        valid_row = False
+                    filter_args.append(field_value)
+                filter_func = FILTER_FUNCS[filter_type]
+                if not filter_func(*filter_args):
+                    valid_row = False
             # Create download URL for file fields.
             if field_entry.value and field_id in file_field_ids:
                 url = reverse("admin:form_file", args=(field_entry.id,))
