@@ -27,7 +27,7 @@ def subject_template(template, context):
 
 
 def send_mail_template(subject, template, addr_from, addr_to, context=None,
-                       attachments=None, fail_silently=False):
+                       attachments=None, fail_silently=False, addr_bcc=None):
     """
     Send email rendering text and html versions for the specified
     template name using the context dictionary passed in.
@@ -43,7 +43,8 @@ def send_mail_template(subject, template, addr_from, addr_to, context=None,
     render = lambda type: loader.get_template("%s.%s" %
                           (template, type)).render(Context(context))
     # Create and send email.
-    msg = EmailMultiAlternatives(subject, render("txt"), addr_from, addr_to)
+    msg = EmailMultiAlternatives(subject, render("txt"),
+                                 addr_from, addr_to, addr_bcc)
     msg.attach_alternative(render("html"), "text/html")
     for attachment in attachments:
         msg.attach(*attachment)
